@@ -5,7 +5,7 @@ To turn on verbose logging
 import logging
 logging.getLogger('calcbench.api_client').setLevel(logging.INFO)
 """
-__version__ = "3.0.8"
+__version__ = "3.0.9"
 from .api_client import (
     CompanyIdentifierScheme,
     as_reported_raw,
@@ -17,7 +17,6 @@ from .api_client import (
     document_types,
     enable_backoff,
     face_statement,
-    filings,
     html_diff,
     mapped_raw,
     normalized_data,
@@ -36,4 +35,5 @@ from .api_client import (
 )
 from .disclosures import document_contents, document_search
 from .companies import tickers, companies, companies_raw
-from .listener import handle_filings
\ No newline at end of file
+from .listener import handle_filings
+from .filing import filings, Filing
