@@ -10,7 +10,7 @@ import json
 import logging
 from typing import Callable
 
-from .api_client import Filing, _cast_filing_fields
+from .filing import Filing
 
 logger = logging.getLogger(__name__)
 
@@ -53,15 +53,16 @@ def handle_filings(
             for message in receiver:
                 body_bytes = b"".join(message.body)
                 try:
-                    filing = json.loads(body_bytes)
-                    filing = _cast_filing_fields(filing)
+                    filing = Filing(**json.loads(body_bytes))
                 except Exception:
                     logger.exception(f"Exception Parsing {body_bytes}")
                     message.abandon()
                 else:
                     try:
+                        logger.info(f"Handling {filing}")
                         handler(filing)
+
                     except Exception as e:
                         logger.exception(f"Exception Processing {filing}\n{e}")
                     else:
-                        message.complete()
+                        message.complete()
\ No newline at end of file
